@@ -86,6 +86,7 @@ class ProcessTracker(object):
                     # and close it. (maybe we should just close it)
                     p.close()
 
+
 class FlappingInfo(object):
     """ object to keep flapping infos """
 
@@ -109,6 +110,7 @@ class ProcessState(object):
     DEFAULT_PARAMS = {
             "group": None,
             "args": None,
+            "env": None,
             "uid": None,
             "gid": None,
             "cwd": None,
@@ -236,14 +238,14 @@ class ProcessState(object):
             lmem.append(info['mem'])
             lcpu.append(info['cpu'])
 
-        if 'N/A' in lmem:
+        if 'N/A' in lmem or not lmem:
             mem, max_mem, min_mem = "N/A"
         else:
             max_mem = max(lmem)
             min_mem = min(lmem)
             mem = sum(lmem)
 
-        if 'N/A' in lcpu:
+        if 'N/A' in lcpu or not lcpu:
             cpu, max_cpu, min_cpu = "N/A"
         else:
             max_cpu = max(lcpu)
